# Decorators API

Visual decorator patterns for print output.

## Decorator Classes

### Line

::: pyreprint.core.decorators.Line

### Header

::: pyreprint.core.decorators.Header

### Box

::: pyreprint.core.decorators.Box

### Banner

::: pyreprint.core.decorators.Banner

## Convenience Functions

### line

::: pyreprint.core.decorators.line

### header

::: pyreprint.core.decorators.header

### box

::: pyreprint.core.decorators.box

### banner

::: pyreprint.core.decorators.banner

